@@ -61,8 +61,8 @@ class SurveyV1API(API):
 
     def search(
         self,
-        survey_name_substring: Optional[str] = None,
-        survey_external_id_substring: Optional[str] = None,
+        name_substring: Optional[str] = None,
+        external_id_substring: Optional[str] = None,
         list_seismics: bool = False,
         list_seismic_stores: bool = False,
         include_metadata: bool = False,
@@ -75,8 +75,8 @@ class SurveyV1API(API):
         Provide either crs or in_wkt to get surveys' coverage.
 
         Args:
-            survey_name_substring (str): find surveys whose name contains this substring
-            survey_external_id_substring (str): find surveys whose external id contains this substring
+            name_substring (str): find surveys whose name contains this substring
+            external_id_substring (str): find surveys whose external id contains this substring
             list_seismics (bool): true if the seismics ids from the surveys should be listed.
             list_seismic_stores (bool): true if seismic stores ids from the surveys should be listed
             include_metadata (bool): true if metadata should be included in the response.
@@ -88,14 +88,14 @@ class SurveyV1API(API):
         Returns:
             List[Survey]: the requested surveys and their files (if requested).
         """
-        if survey_name_substring is None and survey_external_id_substring is None:
+        if name_substring is None and external_id_substring is None:
             raise Exception("either survey_name_substring or survey_external_id_substring must be specified")
 
         search_specs = []
-        if survey_name_substring is not None:
-            search_specs.append(SearchSpec(name_substring=survey_name_substring))
-        if survey_external_id_substring is not None:
-            search_specs.append(SearchSpec(external_id_substring=survey_external_id_substring))
+        if name_substring is not None:
+            search_specs.append(SearchSpec(name_substring=name_substring))
+        if external_id_substring is not None:
+            search_specs.append(SearchSpec(external_id_substring=external_id_substring))
 
         return self._search_internal(
             search_specs,
@@ -110,9 +110,9 @@ class SurveyV1API(API):
 
     def get(
         self,
-        survey_id: Optional[str] = None,
-        survey_external_id: Optional[str] = None,
-        survey_name: Optional[str] = None,
+        id: Optional[str] = None,
+        external_id: Optional[str] = None,
+        name: Optional[str] = None,
         list_seismics: bool = False,
         list_seismic_stores: bool = False,
         include_metadata: bool = False,
@@ -126,9 +126,9 @@ class SurveyV1API(API):
         Provide either crs or in_wkt to get survey coverage.
 
         Args:
-            survey_id (str, optional): survey id.
-            survey_external_id (str, optional): survey external id.
-            survey_name (str, optional): survey name.
+            id (str, optional): survey id.
+            external_id (str, optional): survey external id.
+            name (str, optional): survey name.
             list_seismics (bool): true if the ids of seismics from this survey should be listed.
             list_seismic_stores (bool): true if the ids of seismic stores from this survey should be listed.
             include_metadata (bool): true if metadata should be included in the response.
@@ -141,15 +141,15 @@ class SurveyV1API(API):
             Survey: the requested survey, its seismics, seismic stores and metadata (if requested).
         """
         search_spec = None
-        if survey_id is None and survey_external_id is None and survey_name is None:
+        if id is None and external_id is None and name is None:
             raise Exception("Must specify either survey_id, survey_name or survey_external_id.")
 
-        if survey_id is not None:
-            search_spec = SearchSpec(id_string=survey_id)
-        elif survey_external_id is not None:
-            search_spec = SearchSpec(external_id=survey_external_id)
+        if id is not None:
+            search_spec = SearchSpec(id_string=id)
+        elif external_id is not None:
+            search_spec = SearchSpec(external_id=external_id)
         else:
-            search_spec = SearchSpec(name=survey_name)
+            search_spec = SearchSpec(name=name)
 
         result = self._search_internal(
             [search_spec],
@@ -168,7 +168,7 @@ class SurveyV1API(API):
 
     def register(
         self,
-        survey_name: str,
+        name: str,
         metadata: dict = None,
         external_id: Optional[str] = None,
         crs: Optional[str] = None,
@@ -201,13 +201,13 @@ class SurveyV1API(API):
             RegisterSurveyResponse: id, name and metadata of the survey.
         """
         return self.v0_survey_api.register(
-            survey_name, metadata, external_id, crs, grid_transformation, custom_coverage_wkt, custom_coverage_geojson
+            name, metadata, external_id, crs, grid_transformation, custom_coverage_wkt, custom_coverage_geojson
         )
 
     def edit(
         self,
-        survey_id: Optional[str] = None,
-        survey_name: Optional[str] = None,
+        id: Optional[str] = None,
+        name: Optional[str] = None,
         metadata: dict = None,
         external_id: Optional[str] = None,
         crs: Optional[str] = None,
@@ -219,8 +219,8 @@ class SurveyV1API(API):
         """Edit a survey
 
         Args:
-            survey_id (Optional[str]): id of the survey to edit.
-            survey_name (Optional[str]): name of the survey to edit.
+            id (Optional[str]): id of the survey to edit.
+            name (Optional[str]): name of the survey to edit.
             metadata (dict): metadata of the survey to edit.
             crs (Optional[str]): Coordinate reference system to be used by all
                                  members of this survey
@@ -245,8 +245,8 @@ class SurveyV1API(API):
 
         """
         return self.v0_survey_api.edit(
-            survey_id,
-            survey_name,
+            id,
+            name,
             metadata,
             external_id,
             crs,
@@ -256,18 +256,18 @@ class SurveyV1API(API):
             clear_custom_coverage,
         )
 
-    def delete(self, survey_id: Optional[str] = None, survey_name: Optional[str] = None):
+    def delete(self, id: Optional[str] = None, name: Optional[str] = None):
         """Delete a survey
 
         Args:
-            survey_id (Optional[str]): id of the survey to delete.
-            survey_name (Optional[str]): name of the survey to delete.
+            id (Optional[str]): id of the survey to delete.
+            name (Optional[str]): name of the survey to delete.
 
         Returns:
             Nothing
 
         """
-        return self.v0_survey_api.delete(survey_id, survey_name)
+        return self.v0_survey_api.delete(id, name)
 
     def _search_internal(
         self,
