@@ -63,9 +63,9 @@ class GetVolumeSize(NamedTuple):
     Attributes:
         trace_count: The number of traces that will be streamed
         sample_count: The number of samples in each trace, if available
-        size_kilobytes: An estimate of the total streaming size in kilobytes (= 1024 bytes), 
+        size_kilobytes: An estimate of the total streaming size in kilobytes (= 1024 bytes),
                         or None if sample_count is None
-        """
+    """
 
     trace_count: int
     sample_count: Optional[int]
@@ -248,7 +248,7 @@ class VolumeSeismicAPI(API):
         def alloc(z_size):
             if inline_size * xline_size * z_size > self.ARR_LIM:
                 raise ValueError(
-                    f"Array of size ({inline_size},{xline_size},{z_size}) has more than {self.ARRAY_LIM} elements. Consider restricting the array using inline_range etc."
+                    f"Array of size ({inline_size},{xline_size},{z_size}) has more than {self.ARR_LIM} elements. Consider restricting the array using inline_range etc."
                 )
             return np.ma.masked_all((inline_size, xline_size, z_size), dtype="float")
 
