@@ -197,6 +197,6 @@ class CogniteSeismicClient:
         self.survey_v1 = SurveyV1API(self.seismicstub, self.metadata, self.survey)
         self.volume_seismic = VolumeSeismicAPI(self.seismicstub, self.ingestion, self.metadata)
         self.partition = PartitionAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.seismics = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.seismic = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.seismicstore = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
         self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self.metadata, self)
